<?php

namespace Drupal\cdek_api\Event;

use Symfony\Component\EventDispatcher\Event;
use CdekSDK\Common\Pvz;

/**
 * Defines the pickup point label event.
 *
 * @see \Drupal\cdek_api\Event\CdekApiEvents
 */
class PickupPointLabelEvent extends Event {

  /**
   * The pickup point object.
   *
   * @var \CdekSDK\Common\Pvz
   */
  protected $point;

  /**
   * The pickup point label.
   *
   * @var string
   */
  protected $label;

  /**
   * PickupPointLabelEvent constructor.
   *
   * @param \CdekSDK\Common\Pvz $point
   *   The pickup point object.
   * @param string $label
   *   The pickup point label.
   */
  public function __construct(Pvz $point, $label) {
    $this->point = $point;
    $this->label = $label;
  }

  /**
   * Gets the pickup point object.
   *
   * @return \CdekSDK\Common\Pvz
   *   The pickup point object.
   */
  public function getPoint() {
    return $this->point;
  }

  /**
   * Gets the pickup point label.
   *
   * @return string
   *   The pickup point label.
   */
  public function getLabel() {
    return $this->label;
  }

  /**
   * Sets the pickup point label.
   *
   * @param string $label
   *   The pickup point label.
   *
   * @return $this
   */
  public function setLabel($label) {
    $this->label = $label;
    return $this;
  }

}
